@@ -35,11 +35,10 @@ from zope.traversing.browser import absoluteURL
 
 # import local packages
 from ztfy.jqueryui import jquery_multiselect
-from ztfy.security.browser import ztfy_security
 from ztfy.security.browser.roles import RolesEditForm
 from ztfy.skin.container import ContainerBaseView
 from ztfy.skin.form import EditForm, DisplayForm
-from ztfy.skin.menu import JsMenuItem, MenuItem
+from ztfy.skin.menu import MenuItem, DialogMenuItem
 
 from ztfy.scheduler import _
 
@@ -79,17 +78,6 @@ class SchedulerEditForm(EditForm):
                        """address has been changed without being unregistered!""")
 
 
-class SchedulerRolesMenuItem(JsMenuItem):
-    """Scheduler roles menu item"""
-
-    title = _(":: Roles...")
-
-    def update(self):
-        super(SchedulerRolesMenuItem, self).update()
-        ztfy_security.need()
-        jquery_multiselect.need()
-
-
 class SchedulerRolesEditForm(RolesEditForm):
     """Scheduler roles edit form"""
 
@@ -98,10 +86,11 @@ class SchedulerRolesEditForm(RolesEditForm):
     parent_interface = IScheduler
 
 
-class SchedulerHistoryViewMenu(MenuItem):
-    """Scheduler history view menu"""
+class SchedulerRolesMenuItem(DialogMenuItem):
+    """Scheduler roles menu item"""
 
-    title = _("Tasks run history")
+    title = _(":: Roles...")
+    target = SchedulerRolesEditForm
 
 
 class SchedulerHistoryView(ContainerBaseView):
@@ -125,10 +114,10 @@ class SchedulerHistoryView(ContainerBaseView):
         return super(SchedulerHistoryView, self).renderRow(row, cssClass)
 
 
-class SchedulerTasksViewMenu(MenuItem):
-    """Scheduler tasks view menu"""
+class SchedulerHistoryViewMenu(MenuItem):
+    """Scheduler history view menu"""
 
-    title = _("Tasks")
+    title = _("Tasks run history")
 
 
 class SchedulerTasksView(ContainerBaseView):
@@ -143,10 +132,10 @@ class SchedulerTasksView(ContainerBaseView):
         return IScheduler(self.context).tasks
 
 
-class SchedulerJobsViewMenu(MenuItem):
-    """Scheduler jobs view menu"""
+class SchedulerTasksViewMenu(MenuItem):
+    """Scheduler tasks view menu"""
 
-    title = _("Jobs")
+    title = _("Tasks")
 
 
 class SchedulerJobsView(DisplayForm):
@@ -158,3 +147,9 @@ class SchedulerJobsView(DisplayForm):
     @property
     def jobs(self):
         return removeSecurityProxy(self.context.getJobs())
+
+
+class SchedulerJobsViewMenu(MenuItem):
+    """Scheduler jobs view menu"""
+
+    title = _("Jobs")
